Learn R Programming

rgovcan (version 1.0.3)

govcan_get_resources: Display or Query resources attached to a specific record or (i.e. a CKAN package) or to a stack of packages

Description

Display resources attached to a specific record or (i.e. a CKAN package) or to a stack of packages

Usage

govcan_get_resources(x)

Arguments

x

An object of the class ckan_package_stack or ckan_package, or an id of a specific record or (i.e. a CKAN package).

Value

A object of class ckan_resource_stack or list of ckan_resource_stack objects.

Examples

Run this code
# NOT RUN {
search <- govcan_search("dfo", 10)
id_resources <- govcan_get_resources(search)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab