powered by
Display resources attached to a specific record or (i.e. a CKAN package) or to a stack of packages
govcan_get_resources(x)
An object of the class ckan_package_stack or ckan_package, or an id of a specific record or (i.e. a CKAN package).
ckan_package_stack
ckan_package
A object of class ckan_resource_stack or list of ckan_resource_stack objects.
ckan_resource_stack
# NOT RUN { search <- govcan_search("dfo", 10) id_resources <- govcan_get_resources(search) # } # NOT RUN { # }
Run the code above in your browser using DataLab